pitchtools.is_diatonic_quality_abbreviation
===========================================

.. autofunction:: abjad.tools.pitchtools.is_diatonic_quality_abbreviation.is_diatonic_quality_abbreviation
   :noindex:
